@@ -280,7 +280,9 @@ module.exports = function (grunt) {
             grunt.log.ok('build/umd/min/moment-with-locales.custom.js');
         }).then(function () {
             var moment = require('../build/umd/min/moment-with-locales.custom.js');
-            if (moment.locales().length !== localeFiles.length) {
+            if (moment.locales().filter(function (locale) {
+                return locale !== 'en';
+            }).length !== localeFiles.length) {
                 throw new Error(
                     'You probably specified locales requiring ' +
                     'parent locale, but didn\'t specify parent');
